@@ -7,7 +7,7 @@ except ImportError:
     from PyQt4.QtGui import *
     from PyQt4.QtCore import *
 
-#from PyQt4.QtOpenGL import *
+# from PyQt4.QtOpenGL import *
 
 from libs.shape import Shape
 from libs.utils import distance
@@ -39,20 +39,21 @@ class Canvas(QWidget):
         self.mode = self.EDIT
         self.shapes = []
         self.current = None
-        self.selectedShape = None  # save the selected shape here
-        self.selectedShapeCopy = None
-        self.drawingLineColor = QColor(0, 0, 255)
-        self.drawingRectColor = QColor(0, 0, 255)
-        self.line = Shape(line_color=self.drawingLineColor)
-        self.prevPoint = QPointF()
+        self.selected_shape = None  # save the selected shape here
+        self.selected_shape_copy = None
+        self.drawing_line_color = QColor(0, 0, 255)
+        self.drawing_rect_color = QColor(0, 0, 255)
+        self.line = Shape(line_color=self.drawing_line_color)
+        self.prev_point = QPointF()
         self.offsets = QPointF(), QPointF()
         self.scale = 1.0
+        self.label_font_size = 8
         self.pixmap = QPixmap()
         self.visible = {}
-        self._hideBackround = False
-        self.hideBackround = False
-        self.hShape = None
-        self.hVertex = None
+        self._hide_background = False
+        self.hide_background = False
+        self.h_shape = None
+        self.h_vertex = None
         self._painter = QPainter()
         self._cursor = CURSOR_DEFAULT
         # Menus:
@@ -61,23 +62,23 @@ class Canvas(QWidget):
         self.setMouseTracking(True)
         self.setFocusPolicy(Qt.WheelFocus)
         self.verified = False
-        self.drawSquare = False
+        self.draw_square = False
 
-        #initialisation for panning
+        # initialisation for panning
         self.pan_initial_pos = QPoint()
 
-    def setDrawingColor(self, qColor):
-        self.drawingLineColor = qColor
-        self.drawingRectColor = qColor
+    def set_drawing_color(self, qcolor):
+        self.drawing_line_color = qcolor
+        self.drawing_rect_color = qcolor
 
     def enterEvent(self, ev):
-        self.overrideCursor(self._cursor)
+        self.override_cursor(self._cursor)
 
     def leaveEvent(self, ev):
-        self.restoreCursor()
+        self.restore_cursor()
 
     def focusOutEvent(self, ev):
-        self.restoreCursor()
+        self.restore_cursor()
 
     def isVisible(self, shape):
         return self.visible.get(shape, True)
@@ -88,44 +89,44 @@ class Canvas(QWidget):
     def editing(self):
         return self.mode == self.EDIT
 
-    def setEditing(self, value=True):
+    def set_editing(self, value=True):
         self.mode = self.EDIT if value else self.CREATE
         if not value:  # Create
-            self.unHighlight()
-            self.deSelectShape()
-        self.prevPoint = QPointF()
+            self.un_highlight()
+            self.de_select_shape()
+        self.prev_point = QPointF()
         self.repaint()
 
-    def unHighlight(self):
-        if self.hShape:
-            self.hShape.highlightClear()
-        self.hVertex = self.hShape = None
+    def un_highlight(self):
+        if self.h_shape:
+            self.h_shape.highlight_clear()
+        self.h_vertex = self.h_shape = None
 
-    def selectedVertex(self):
-        return self.hVertex is not None
+    def selected_vertex(self):
+        return self.h_vertex is not None
 
     def mouseMoveEvent(self, ev):
         """Update line with last point and current coordinates."""
-        pos = self.transformPos(ev.pos())
+        pos = self.transform_pos(ev.pos())
 
         # Update coordinates in status bar if image is opened
         window = self.parent().window()
-        if window.filePath is not None:
-            self.parent().window().labelCoordinates.setText(
+        if window.file_path is not None:
+            self.parent().window().label_coordinates.setText(
                 'X: %d; Y: %d' % (pos.x(), pos.y()))
 
         # Polygon drawing.
         if self.drawing():
-            self.overrideCursor(CURSOR_DRAW)
+            self.override_cursor(CURSOR_DRAW)
             if self.current:
                 # Display annotation width and height while drawing
-                currentWidth = abs(self.current[0].x() - pos.x())
-                currentHeight = abs(self.current[0].y() - pos.y())
-                self.parent().window().labelCoordinates.setText(
-                        'Width: %d, Height: %d / X: %d; Y: %d' % (currentWidth, currentHeight, pos.x(), pos.y()))
+                current_width = abs(self.current[0].x() - pos.x())
+                current_height = abs(self.current[0].y() - pos.y())
+                self.parent().window().label_coordinates.setText(
+                        'Width: %d, Height: %d / X: %d; Y: %d' % (current_width, current_height, pos.x(), pos.y()))
 
-                color = self.drawingLineColor
-                if self.outOfPixmap(pos):
+                color = self.drawing_line_color
+                if self.out_of_pixmap(pos):
                     # Don't allow the user to draw outside the pixmap.
                     # Clip the coordinates to 0 or max,
                     # if they are outside the range [0, max]
@@ -133,57 +134,57 @@ class Canvas(QWidget):
                     clipped_x = min(max(0, pos.x()), size.width())
                     clipped_y = min(max(0, pos.y()), size.height())
                     pos = QPointF(clipped_x, clipped_y)
-                elif len(self.current) > 1 and self.closeEnough(pos, self.current[0]):
+                elif len(self.current) > 1 and self.close_enough(pos, self.current[0]):
                     # Attract line to starting point and colorise to alert the
                     # user:
                     pos = self.current[0]
                     color = self.current.line_color
-                    self.overrideCursor(CURSOR_POINT)
-                    self.current.highlightVertex(0, Shape.NEAR_VERTEX)
+                    self.override_cursor(CURSOR_POINT)
+                    self.current.highlight_vertex(0, Shape.NEAR_VERTEX)
 
-                if self.drawSquare:
-                    initPos = self.current[0]
-                    minX = initPos.x()
-                    minY = initPos.y()
-                    min_size = min(abs(pos.x() - minX), abs(pos.y() - minY))
-                    directionX = -1 if pos.x() - minX < 0 else 1
-                    directionY = -1 if pos.y() - minY < 0 else 1
-                    self.line[1] = QPointF(minX + directionX * min_size, minY + directionY * min_size)
+                if self.draw_square:
+                    init_pos = self.current[0]
+                    min_x = init_pos.x()
+                    min_y = init_pos.y()
+                    min_size = min(abs(pos.x() - min_x), abs(pos.y() - min_y))
+                    direction_x = -1 if pos.x() - min_x < 0 else 1
+                    direction_y = -1 if pos.y() - min_y < 0 else 1
+                    self.line[1] = QPointF(min_x + direction_x * min_size, min_y + direction_y * min_size)
                 else:
                     self.line[1] = pos
 
                 self.line.line_color = color
-                self.prevPoint = QPointF()
-                self.current.highlightClear()
+                self.prev_point = QPointF()
+                self.current.highlight_clear()
             else:
-                self.prevPoint = pos
+                self.prev_point = pos
             self.repaint()
             return
 
         # Polygon copy moving.
         if Qt.RightButton & ev.buttons():
-            if self.selectedShapeCopy and self.prevPoint:
-                self.overrideCursor(CURSOR_MOVE)
-                self.boundedMoveShape(self.selectedShapeCopy, pos)
+            if self.selected_shape_copy and self.prev_point:
+                self.override_cursor(CURSOR_MOVE)
+                self.bounded_move_shape(self.selected_shape_copy, pos)
                 self.repaint()
-            elif self.selectedShape:
-                self.selectedShapeCopy = self.selectedShape.copy()
+            elif self.selected_shape:
+                self.selected_shape_copy = self.selected_shape.copy()
                 self.repaint()
             return
 
         # Polygon/Vertex moving.
         if Qt.LeftButton & ev.buttons():
-            if self.selectedVertex():
-                self.boundedMoveVertex(pos)
+            if self.selected_vertex():
+                self.bounded_move_vertex(pos)
                 self.shapeMoved.emit()
                 self.repaint()
-            elif self.selectedShape and self.prevPoint:
-                self.overrideCursor(CURSOR_MOVE)
-                self.boundedMoveShape(self.selectedShape, pos)
+            elif self.selected_shape and self.prev_point:
+                self.override_cursor(CURSOR_MOVE)
+                self.bounded_move_shape(self.selected_shape, pos)
                 self.shapeMoved.emit()
                 self.repaint()
             else:
-                #pan
+                # pan
                 delta_x = pos.x() - self.pan_initial_pos.x()
                 delta_y = pos.y() - self.pan_initial_pos.y()
                 self.scrollRequest.emit(delta_x, Qt.Horizontal)
@@ -191,7 +192,7 @@ class Canvas(QWidget):
                 self.update()
             return
 
-        # Just hovering over the canvas, 2 posibilities:
+        # Just hovering over the canvas, 2 possibilities:
         # - Highlight shapes
         # - Highlight vertex
         # Update shape/vertex fill and tooltip value accordingly.
@@ -199,163 +200,163 @@ class Canvas(QWidget):
         for shape in reversed([s for s in self.shapes if self.isVisible(s)]):
             # Look for a nearby vertex to highlight. If that fails,
             # check if we happen to be inside a shape.
-            index = shape.nearestVertex(pos, self.epsilon)
+            index = shape.nearest_vertex(pos, self.epsilon)
             if index is not None:
-                if self.selectedVertex():
-                    self.hShape.highlightClear()
-                self.hVertex, self.hShape = index, shape
-                shape.highlightVertex(index, shape.MOVE_VERTEX)
-                self.overrideCursor(CURSOR_POINT)
+                if self.selected_vertex():
+                    self.h_shape.highlight_clear()
+                self.h_vertex, self.h_shape = index, shape
+                shape.highlight_vertex(index, shape.MOVE_VERTEX)
+                self.override_cursor(CURSOR_POINT)
                 self.setToolTip("Click & drag to move point")
                 self.setStatusTip(self.toolTip())
                 self.update()
                 break
-            elif shape.containsPoint(pos):
-                if self.selectedVertex():
-                    self.hShape.highlightClear()
-                self.hVertex, self.hShape = None, shape
+            elif shape.contains_point(pos):
+                if self.selected_vertex():
+                    self.h_shape.highlight_clear()
+                self.h_vertex, self.h_shape = None, shape
                 self.setToolTip(
                     "Click & drag to move shape '%s'" % shape.label)
                 self.setStatusTip(self.toolTip())
-                self.overrideCursor(CURSOR_GRAB)
+                self.override_cursor(CURSOR_GRAB)
                 self.update()
                 break
         else:  # Nothing found, clear highlights, reset state.
-            if self.hShape:
-                self.hShape.highlightClear()
+            if self.h_shape:
+                self.h_shape.highlight_clear()
                 self.update()
-            self.hVertex, self.hShape = None, None
-            self.overrideCursor(CURSOR_DEFAULT)
+            self.h_vertex, self.h_shape = None, None
+            self.override_cursor(CURSOR_DEFAULT)
 
     def mousePressEvent(self, ev):
-        pos = self.transformPos(ev.pos())
+        pos = self.transform_pos(ev.pos())
 
         if ev.button() == Qt.LeftButton:
             if self.drawing():
-                self.handleDrawing(pos)
+                self.handle_drawing(pos)
             else:
-                selection = self.selectShapePoint(pos)
-                self.prevPoint = pos
+                selection = self.select_shape_point(pos)
+                self.prev_point = pos
 
                 if selection is None:
-                    #pan
+                    # pan
                     QApplication.setOverrideCursor(QCursor(Qt.OpenHandCursor))
                     self.pan_initial_pos = pos
 
         elif ev.button() == Qt.RightButton and self.editing():
-            self.selectShapePoint(pos)
-            self.prevPoint = pos
+            self.select_shape_point(pos)
+            self.prev_point = pos
         self.update()
 
     def mouseReleaseEvent(self, ev):
         if ev.button() == Qt.RightButton:
-            menu = self.menus[bool(self.selectedShapeCopy)]
-            self.restoreCursor()
+            menu = self.menus[bool(self.selected_shape_copy)]
+            self.restore_cursor()
             if not menu.exec_(self.mapToGlobal(ev.pos()))\
-               and self.selectedShapeCopy:
+               and self.selected_shape_copy:
                 # Cancel the move by deleting the shadow copy.
-                self.selectedShapeCopy = None
+                self.selected_shape_copy = None
                 self.repaint()
-        elif ev.button() == Qt.LeftButton and self.selectedShape:
-            if self.selectedVertex():
-                self.overrideCursor(CURSOR_POINT)
+        elif ev.button() == Qt.LeftButton and self.selected_shape:
+            if self.selected_vertex():
+                self.override_cursor(CURSOR_POINT)
             else:
-                self.overrideCursor(CURSOR_GRAB)
+                self.override_cursor(CURSOR_GRAB)
         elif ev.button() == Qt.LeftButton:
-            pos = self.transformPos(ev.pos())
+            pos = self.transform_pos(ev.pos())
             if self.drawing():
-                self.handleDrawing(pos)
+                self.handle_drawing(pos)
             else:
-                #pan
+                # pan
                 QApplication.restoreOverrideCursor()
 
-    def endMove(self, copy=False):
-        assert self.selectedShape and self.selectedShapeCopy
-        shape = self.selectedShapeCopy
-        #del shape.fill_color
-        #del shape.line_color
+    def end_move(self, copy=False):
+        assert self.selected_shape and self.selected_shape_copy
+        shape = self.selected_shape_copy
+        # del shape.fill_color
+        # del shape.line_color
         if copy:
             self.shapes.append(shape)
-            self.selectedShape.selected = False
-            self.selectedShape = shape
+            self.selected_shape.selected = False
+            self.selected_shape = shape
             self.repaint()
         else:
-            self.selectedShape.points = [p for p in shape.points]
-        self.selectedShapeCopy = None
+            self.selected_shape.points = [p for p in shape.points]
+        self.selected_shape_copy = None
 
-    def hideBackroundShapes(self, value):
-        self.hideBackround = value
-        if self.selectedShape:
+    def hide_background_shapes(self, value):
+        self.hide_background = value
+        if self.selected_shape:
             # Only hide other shapes if there is a current selection.
             # Otherwise the user will not be able to select a shape.
-            self.setHiding(True)
+            self.set_hiding(True)
             self.repaint()
 
-    def handleDrawing(self, pos):
-        if self.current and self.current.reachMaxPoints() is False:
-            initPos = self.current[0]
-            minX = initPos.x()
-            minY = initPos.y()
-            targetPos = self.line[1]
-            maxX = targetPos.x()
-            maxY = targetPos.y()
-            self.current.addPoint(QPointF(maxX, minY))
-            self.current.addPoint(targetPos)
-            self.current.addPoint(QPointF(minX, maxY))
+    def handle_drawing(self, pos):
+        if self.current and self.current.reach_max_points() is False:
+            init_pos = self.current[0]
+            min_x = init_pos.x()
+            min_y = init_pos.y()
+            target_pos = self.line[1]
+            max_x = target_pos.x()
+            max_y = target_pos.y()
+            self.current.add_point(QPointF(max_x, min_y))
+            self.current.add_point(target_pos)
+            self.current.add_point(QPointF(min_x, max_y))
             self.finalise()
-        elif not self.outOfPixmap(pos):
+        elif not self.out_of_pixmap(pos):
             self.current = Shape()
-            self.current.addPoint(pos)
+            self.current.add_point(pos)
             self.line.points = [pos, pos]
-            self.setHiding()
+            self.set_hiding()
             self.drawingPolygon.emit(True)
             self.update()
 
-    def setHiding(self, enable=True):
-        self._hideBackround = self.hideBackround if enable else False
+    def set_hiding(self, enable=True):
+        self._hide_background = self.hide_background if enable else False
 
-    def canCloseShape(self):
+    def can_close_shape(self):
         return self.drawing() and self.current and len(self.current) > 2
 
     def mouseDoubleClickEvent(self, ev):
         # We need at least 4 points here, since the mousePress handler
         # adds an extra one before this handler is called.
-        if self.canCloseShape() and len(self.current) > 3:
-            self.current.popPoint()
+        if self.can_close_shape() and len(self.current) > 3:
+            self.current.pop_point()
             self.finalise()
 
-    def selectShape(self, shape):
-        self.deSelectShape()
+    def select_shape(self, shape):
+        self.de_select_shape()
         shape.selected = True
-        self.selectedShape = shape
-        self.setHiding()
+        self.selected_shape = shape
+        self.set_hiding()
         self.selectionChanged.emit(True)
         self.update()
 
-    def selectShapePoint(self, point):
+    def select_shape_point(self, point):
         """Select the first shape created which contains this point."""
-        self.deSelectShape()
-        if self.selectedVertex():  # A vertex is marked for selection.
-            index, shape = self.hVertex, self.hShape
-            shape.highlightVertex(index, shape.MOVE_VERTEX)
-            self.selectShape(shape)
-            return self.hVertex
+        self.de_select_shape()
+        if self.selected_vertex():  # A vertex is marked for selection.
+            index, shape = self.h_vertex, self.h_shape
+            shape.highlight_vertex(index, shape.MOVE_VERTEX)
+            self.select_shape(shape)
+            return self.h_vertex
         for shape in reversed(self.shapes):
-            if self.isVisible(shape) and shape.containsPoint(point):
-                self.selectShape(shape)
-                self.calculateOffsets(shape, point)
-                return self.selectedShape
+            if self.isVisible(shape) and shape.contains_point(point):
+                self.select_shape(shape)
+                self.calculate_offsets(shape, point)
+                return self.selected_shape
         return None
 
-    def calculateOffsets(self, shape, point):
-        rect = shape.boundingRect()
+    def calculate_offsets(self, shape, point):
+        rect = shape.bounding_rect()
         x1 = rect.x() - point.x()
         y1 = rect.y() - point.y()
         x2 = (rect.x() + rect.width()) - point.x()
         y2 = (rect.y() + rect.height()) - point.y()
         self.offsets = QPointF(x1, y1), QPointF(x2, y2)
 
-    def snapPointToCanvas(self, x, y):
+    def snap_point_to_canvas(self, x, y):
         """
         Moves a point x,y to within the boundaries of the canvas.
         :return: (x,y,snapped) where snapped is True if x or y were changed, False if not.
@@ -369,99 +370,99 @@ class Canvas(QWidget):
 
         return x, y, False
 
-    def boundedMoveVertex(self, pos):
-        index, shape = self.hVertex, self.hShape
+    def bounded_move_vertex(self, pos):
+        index, shape = self.h_vertex, self.h_shape
         point = shape[index]
-        if self.outOfPixmap(pos):
+        if self.out_of_pixmap(pos):
             size = self.pixmap.size()
             clipped_x = min(max(0, pos.x()), size.width())
             clipped_y = min(max(0, pos.y()), size.height())
             pos = QPointF(clipped_x, clipped_y)
 
-        if self.drawSquare:
+        if self.draw_square:
             opposite_point_index = (index + 2) % 4
             opposite_point = shape[opposite_point_index]
 
             min_size = min(abs(pos.x() - opposite_point.x()), abs(pos.y() - opposite_point.y()))
-            directionX = -1 if pos.x() - opposite_point.x() < 0 else 1
-            directionY = -1 if pos.y() - opposite_point.y() < 0 else 1
-            shiftPos = QPointF(opposite_point.x() + directionX * min_size - point.x(),
-                               opposite_point.y() + directionY * min_size - point.y())
+            direction_x = -1 if pos.x() - opposite_point.x() < 0 else 1
+            direction_y = -1 if pos.y() - opposite_point.y() < 0 else 1
+            shift_pos = QPointF(opposite_point.x() + direction_x * min_size - point.x(),
+                                opposite_point.y() + direction_y * min_size - point.y())
         else:
-            shiftPos = pos - point
+            shift_pos = pos - point
 
-        shape.moveVertexBy(index, shiftPos)
+        shape.move_vertex_by(index, shift_pos)
 
-        lindex = (index + 1) % 4
-        rindex = (index + 3) % 4
-        lshift = None
-        rshift = None
+        left_index = (index + 1) % 4
+        right_index = (index + 3) % 4
+        left_shift = None
+        right_shift = None
         if index % 2 == 0:
-            rshift = QPointF(shiftPos.x(), 0)
-            lshift = QPointF(0, shiftPos.y())
+            right_shift = QPointF(shift_pos.x(), 0)
+            left_shift = QPointF(0, shift_pos.y())
         else:
-            lshift = QPointF(shiftPos.x(), 0)
-            rshift = QPointF(0, shiftPos.y())
-        shape.moveVertexBy(rindex, rshift)
-        shape.moveVertexBy(lindex, lshift)
+            left_shift = QPointF(shift_pos.x(), 0)
+            right_shift = QPointF(0, shift_pos.y())
+        shape.move_vertex_by(right_index, right_shift)
+        shape.move_vertex_by(left_index, left_shift)
 
-    def boundedMoveShape(self, shape, pos):
-        if self.outOfPixmap(pos):
+    def bounded_move_shape(self, shape, pos):
+        if self.out_of_pixmap(pos):
             return False  # No need to move
         o1 = pos + self.offsets[0]
-        if self.outOfPixmap(o1):
+        if self.out_of_pixmap(o1):
             pos -= QPointF(min(0, o1.x()), min(0, o1.y()))
         o2 = pos + self.offsets[1]
-        if self.outOfPixmap(o2):
+        if self.out_of_pixmap(o2):
             pos += QPointF(min(0, self.pixmap.width() - o2.x()),
                            min(0, self.pixmap.height() - o2.y()))
         # The next line tracks the new position of the cursor
         # relative to the shape, but also results in making it
         # a bit "shaky" when nearing the border and allows it to
         # go outside of the shape's area for some reason. XXX
-        #self.calculateOffsets(self.selectedShape, pos)
-        dp = pos - self.prevPoint
+        # self.calculateOffsets(self.selectedShape, pos)
+        dp = pos - self.prev_point
         if dp:
-            shape.moveBy(dp)
-            self.prevPoint = pos
+            shape.move_by(dp)
+            self.prev_point = pos
             return True
         return False
 
-    def deSelectShape(self):
-        if self.selectedShape:
-            self.selectedShape.selected = False
-            self.selectedShape = None
-            self.setHiding(False)
+    def de_select_shape(self):
+        if self.selected_shape:
+            self.selected_shape.selected = False
+            self.selected_shape = None
+            self.set_hiding(False)
             self.selectionChanged.emit(False)
             self.update()
 
-    def deleteSelected(self):
-        if self.selectedShape:
-            shape = self.selectedShape
-            self.shapes.remove(self.selectedShape)
-            self.selectedShape = None
+    def delete_selected(self):
+        if self.selected_shape:
+            shape = self.selected_shape
+            self.shapes.remove(self.selected_shape)
+            self.selected_shape = None
             self.update()
             return shape
 
-    def copySelectedShape(self):
-        if self.selectedShape:
-            shape = self.selectedShape.copy()
-            self.deSelectShape()
+    def copy_selected_shape(self):
+        if self.selected_shape:
+            shape = self.selected_shape.copy()
+            self.de_select_shape()
             self.shapes.append(shape)
             shape.selected = True
-            self.selectedShape = shape
-            self.boundedShiftShape(shape)
+            self.selected_shape = shape
+            self.bounded_shift_shape(shape)
             return shape
 
-    def boundedShiftShape(self, shape):
+    def bounded_shift_shape(self, shape):
         # Try to move in one direction, and if it fails in another.
         # Give up if both fail.
         point = shape[0]
         offset = QPointF(2.0, 2.0)
-        self.calculateOffsets(shape, point)
-        self.prevPoint = point
-        if not self.boundedMoveShape(shape, point - offset):
-            self.boundedMoveShape(shape, point + offset)
+        self.calculate_offsets(shape, point)
+        self.prev_point = point
+        if not self.bounded_move_shape(shape, point - offset):
+            self.bounded_move_shape(shape, point + offset)
 
     def paintEvent(self, event):
         if not self.pixmap:
@@ -474,35 +475,36 @@ class Canvas(QWidget):
         p.setRenderHint(QPainter.SmoothPixmapTransform)
 
         p.scale(self.scale, self.scale)
-        p.translate(self.offsetToCenter())
+        p.translate(self.offset_to_center())
 
         p.drawPixmap(0, 0, self.pixmap)
         Shape.scale = self.scale
+        Shape.label_font_size = self.label_font_size
         for shape in self.shapes:
-            if (shape.selected or not self._hideBackround) and self.isVisible(shape):
-                shape.fill = shape.selected or shape == self.hShape
+            if (shape.selected or not self._hide_background) and self.isVisible(shape):
+                shape.fill = shape.selected or shape == self.h_shape
                 shape.paint(p)
         if self.current:
             self.current.paint(p)
             self.line.paint(p)
-        if self.selectedShapeCopy:
-            self.selectedShapeCopy.paint(p)
+        if self.selected_shape_copy:
+            self.selected_shape_copy.paint(p)
 
         # Paint rect
         if self.current is not None and len(self.line) == 2:
-            leftTop = self.line[0]
-            rightBottom = self.line[1]
-            rectWidth = rightBottom.x() - leftTop.x()
-            rectHeight = rightBottom.y() - leftTop.y()
-            p.setPen(self.drawingRectColor)
+            left_top = self.line[0]
+            right_bottom = self.line[1]
+            rect_width = right_bottom.x() - left_top.x()
+            rect_height = right_bottom.y() - left_top.y()
+            p.setPen(self.drawing_rect_color)
             brush = QBrush(Qt.BDiagPattern)
             p.setBrush(brush)
-            p.drawRect(leftTop.x(), leftTop.y(), rectWidth, rectHeight)
+            p.drawRect(left_top.x(), left_top.y(), rect_width, rect_height)
 
-        if self.drawing() and not self.prevPoint.isNull() and not self.outOfPixmap(self.prevPoint):
+        if self.drawing() and not self.prev_point.isNull() and not self.out_of_pixmap(self.prev_point):
             p.setPen(QColor(0, 0, 0))
-            p.drawLine(self.prevPoint.x(), 0, self.prevPoint.x(), self.pixmap.height())
-            p.drawLine(0, self.prevPoint.y(), self.pixmap.width(), self.prevPoint.y())
+            p.drawLine(self.prev_point.x(), 0, self.prev_point.x(), self.pixmap.height())
+            p.drawLine(0, self.prev_point.y(), self.pixmap.width(), self.prev_point.y())
 
         self.setAutoFillBackground(True)
         if self.verified:
@@ -516,11 +518,11 @@ class Canvas(QWidget):
 
         p.end()
 
-    def transformPos(self, point):
+    def transform_pos(self, point):
         """Convert from widget-logical coordinates to painter-logical coordinates."""
-        return point / self.scale - self.offsetToCenter()
+        return point / self.scale - self.offset_to_center()
 
-    def offsetToCenter(self):
+    def offset_to_center(self):
         s = self.scale
         area = super(Canvas, self).size()
         w, h = self.pixmap.width() * s, self.pixmap.height() * s
@@ -529,7 +531,7 @@ class Canvas(QWidget):
         y = (ah - h) / (2 * s) if ah > h else 0
         return QPointF(x, y)
 
-    def outOfPixmap(self, p):
+    def out_of_pixmap(self, p):
         w, h = self.pixmap.width(), self.pixmap.height()
         return not (0 <= p.x() <= w and 0 <= p.y() <= h)
 
@@ -544,13 +546,13 @@ class Canvas(QWidget):
         self.current.close()
         self.shapes.append(self.current)
         self.current = None
-        self.setHiding(False)
+        self.set_hiding(False)
         self.newShape.emit()
         self.update()
 
-    def closeEnough(self, p1, p2):
-        #d = distance(p1 - p2)
-        #m = (p1-p2).manhattanLength()
+    def close_enough(self, p1, p2):
+        # d = distance(p1 - p2)
+        # m = (p1-p2).manhattanLength()
         # print "d %.2f, m %d, %.2f" % (d, m, d - m)
         return distance(p1 - p2) < self.epsilon
 
@@ -593,51 +595,51 @@ class Canvas(QWidget):
             self.current = None
             self.drawingPolygon.emit(False)
             self.update()
-        elif key == Qt.Key_Return and self.canCloseShape():
+        elif key == Qt.Key_Return and self.can_close_shape():
             self.finalise()
-        elif key == Qt.Key_Left and self.selectedShape:
-            self.moveOnePixel('Left')
-        elif key == Qt.Key_Right and self.selectedShape:
-            self.moveOnePixel('Right')
-        elif key == Qt.Key_Up and self.selectedShape:
-            self.moveOnePixel('Up')
-        elif key == Qt.Key_Down and self.selectedShape:
-            self.moveOnePixel('Down')
+        elif key == Qt.Key_Left and self.selected_shape:
+            self.move_one_pixel('Left')
+        elif key == Qt.Key_Right and self.selected_shape:
+            self.move_one_pixel('Right')
+        elif key == Qt.Key_Up and self.selected_shape:
+            self.move_one_pixel('Up')
+        elif key == Qt.Key_Down and self.selected_shape:
+            self.move_one_pixel('Down')
 
-    def moveOnePixel(self, direction):
+    def move_one_pixel(self, direction):
         # print(self.selectedShape.points)
-        if direction == 'Left' and not self.moveOutOfBound(QPointF(-1.0, 0)):
+        if direction == 'Left' and not self.move_out_of_bound(QPointF(-1.0, 0)):
             # print("move Left one pixel")
-            self.selectedShape.points[0] += QPointF(-1.0, 0)
-            self.selectedShape.points[1] += QPointF(-1.0, 0)
-            self.selectedShape.points[2] += QPointF(-1.0, 0)
-            self.selectedShape.points[3] += QPointF(-1.0, 0)
-        elif direction == 'Right' and not self.moveOutOfBound(QPointF(1.0, 0)):
+            self.selected_shape.points[0] += QPointF(-1.0, 0)
+            self.selected_shape.points[1] += QPointF(-1.0, 0)
+            self.selected_shape.points[2] += QPointF(-1.0, 0)
+            self.selected_shape.points[3] += QPointF(-1.0, 0)
+        elif direction == 'Right' and not self.move_out_of_bound(QPointF(1.0, 0)):
             # print("move Right one pixel")
-            self.selectedShape.points[0] += QPointF(1.0, 0)
-            self.selectedShape.points[1] += QPointF(1.0, 0)
-            self.selectedShape.points[2] += QPointF(1.0, 0)
-            self.selectedShape.points[3] += QPointF(1.0, 0)
-        elif direction == 'Up' and not self.moveOutOfBound(QPointF(0, -1.0)):
+            self.selected_shape.points[0] += QPointF(1.0, 0)
+            self.selected_shape.points[1] += QPointF(1.0, 0)
+            self.selected_shape.points[2] += QPointF(1.0, 0)
+            self.selected_shape.points[3] += QPointF(1.0, 0)
+        elif direction == 'Up' and not self.move_out_of_bound(QPointF(0, -1.0)):
             # print("move Up one pixel")
-            self.selectedShape.points[0] += QPointF(0, -1.0)
-            self.selectedShape.points[1] += QPointF(0, -1.0)
-            self.selectedShape.points[2] += QPointF(0, -1.0)
-            self.selectedShape.points[3] += QPointF(0, -1.0)
-        elif direction == 'Down' and not self.moveOutOfBound(QPointF(0, 1.0)):
+            self.selected_shape.points[0] += QPointF(0, -1.0)
+            self.selected_shape.points[1] += QPointF(0, -1.0)
+            self.selected_shape.points[2] += QPointF(0, -1.0)
+            self.selected_shape.points[3] += QPointF(0, -1.0)
+        elif direction == 'Down' and not self.move_out_of_bound(QPointF(0, 1.0)):
             # print("move Down one pixel")
-            self.selectedShape.points[0] += QPointF(0, 1.0)
-            self.selectedShape.points[1] += QPointF(0, 1.0)
-            self.selectedShape.points[2] += QPointF(0, 1.0)
-            self.selectedShape.points[3] += QPointF(0, 1.0)
+            self.selected_shape.points[0] += QPointF(0, 1.0)
+            self.selected_shape.points[1] += QPointF(0, 1.0)
+            self.selected_shape.points[2] += QPointF(0, 1.0)
+            self.selected_shape.points[3] += QPointF(0, 1.0)
         self.shapeMoved.emit()
         self.repaint()
 
-    def moveOutOfBound(self, step):
-        points = [p1+p2 for p1, p2 in zip(self.selectedShape.points, [step]*4)]
-        return True in map(self.outOfPixmap, points)
+    def move_out_of_bound(self, step):
+        points = [p1 + p2 for p1, p2 in zip(self.selected_shape.points, [step] * 4)]
+        return True in map(self.out_of_pixmap, points)
 
-    def setLastLabel(self, text, line_color  = None, fill_color = None):
+    def set_last_label(self, text, line_color=None, fill_color=None):
         assert text
         self.shapes[-1].label = text
         if line_color:
@@ -648,57 +650,57 @@ class Canvas(QWidget):
 
         return self.shapes[-1]
 
-    def undoLastLine(self):
+    def undo_last_line(self):
         assert self.shapes
         self.current = self.shapes.pop()
-        self.current.setOpen()
+        self.current.set_open()
         self.line.points = [self.current[-1], self.current[0]]
         self.drawingPolygon.emit(True)
 
-    def resetAllLines(self):
+    def reset_all_lines(self):
         assert self.shapes
         self.current = self.shapes.pop()
-        self.current.setOpen()
+        self.current.set_open()
         self.line.points = [self.current[-1], self.current[0]]
         self.drawingPolygon.emit(True)
         self.current = None
         self.drawingPolygon.emit(False)
         self.update()
 
-    def loadPixmap(self, pixmap):
+    def load_pixmap(self, pixmap):
         self.pixmap = pixmap
         self.shapes = []
         self.repaint()
 
-    def loadShapes(self, shapes):
+    def load_shapes(self, shapes):
         self.shapes = list(shapes)
         self.current = None
         self.repaint()
 
-    def setShapeVisible(self, shape, value):
+    def set_shape_visible(self, shape, value):
         self.visible[shape] = value
         self.repaint()
 
-    def currentCursor(self):
+    def current_cursor(self):
         cursor = QApplication.overrideCursor()
         if cursor is not None:
             cursor = cursor.shape()
         return cursor
 
-    def overrideCursor(self, cursor):
+    def override_cursor(self, cursor):
         self._cursor = cursor
-        if self.currentCursor() is None:
+        if self.current_cursor() is None:
             QApplication.setOverrideCursor(cursor)
         else:
             QApplication.changeOverrideCursor(cursor)
 
-    def restoreCursor(self):
+    def restore_cursor(self):
         QApplication.restoreOverrideCursor()
 
-    def resetState(self):
-        self.restoreCursor()
+    def reset_state(self):
+        self.restore_cursor()
         self.pixmap = None
         self.update()
 
-    def setDrawingShapeToSquare(self, status):
-        self.drawSquare = status
+    def set_drawing_shape_to_square(self, status):
+        self.draw_square = status
